package
Version:
v0.0.0-...-e2e8ca1
Opens a new window with list of versions in this module.
Published: Mar 18, 2025
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type EventReceiver interface {
ReceiveEvents() <-chan fs.FileEvent
}
type JoinListener interface {
JoinedPeerListener() <-chan p2p.Peer
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.